// java wrapper for vtkMultiNewickTreeReader object
//

package vtk;
import vtk.*;

public class vtkMultiNewickTreeReader extends vtkDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkMultiPieceDataSet GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkMultiPieceDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkMultiPieceDataSet GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkMultiPieceDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutput_4(vtkMultiPieceDataSet id0);
  public void SetOutput(vtkMultiPieceDataSet id0)
    { SetOutput_4(id0); }

  private native int ReadMeshSimple_5(String id0,vtkDataObject id1);
  public int ReadMeshSimple(String id0,vtkDataObject id1)
    { return ReadMeshSimple_5(id0,id1); }

  public vtkMultiNewickTreeReader() { super(); }

  public vtkMultiNewickTreeReader(long id) { super(id); }
  public native long   VTKInit();

}
